/*!\file:  TransformLoadVectorCoord.cpp
 * \brief transform load vector coordinate system
 */ 
#include "./elements.h"

void TransformLoadVectorCoord(ElementVector* pe,Node** nodes,int numnodes,int cs_enum){
	int* cs_array=NULL;

	/*All nodes have the same Coordinate System*/
	cs_array=xNew<int>(numnodes);
	for(int i=0;i<numnodes;i++) cs_array[i]=cs_enum;

	/*Call core*/
	TransformLoadVectorCoord(pe,nodes,numnodes,cs_array);

	/*Clean-up*/
	xDelete<int>(cs_array);
}

void TransformLoadVectorCoord(ElementVector* pe,Node** nodes,int numnodes,int* cs_array){

	int     i,j;
	int     numdofs   = 0;
	double *transform = NULL;
	double *values    = NULL;

	/*Get total number of dofs*/
	for(i=0;i<numnodes;i++){
		switch(cs_array[i]){
			case XYEnum:   numdofs+=2; break;
			case XYZPEnum: numdofs+=4; break;
			default: _error_("Coordinate system %s not supported yet",EnumToStringx(cs_array[i]));
		}
	}

	/*Copy current load vector*/
	values=xNew<double>(pe->nrows);
	for(i=0;i<pe->nrows;i++) values[i]=pe->values[i];

	/*Get Coordinate Systems transform matrix*/
	CoordinateSystemTransform(&transform,nodes,numnodes,cs_array);

	/*Transform matrix: R^T*pe */
	MatrixMultiply(transform,numdofs,numdofs,1,
				values,pe->nrows,1,0,
				&pe->values[0],0);

	/*Free Matrices*/
	xDelete<double>(transform);
	xDelete<double>(values);
}
